@@ -5,29 +5,16 @@ use warnings;
 
 # ABSTRACT: A encoding conversion processor
 
-our $VERSION = '1.111450'; # VERSION
+our $VERSION = '1.111480'; # VERSION
 
 use Moose;
 extends 'DataFlow::Proc';
 
-use Moose::Util::TypeConstraints 1.01;
+use DataFlow::Types qw(Encoder Decoder);
 
 use namespace::autoclean;
-use Encode;
 use MooseX::Aliases;
 
-subtype 'Decoder' => as 'CodeRef';
-coerce 'Decoder' => from 'Str' => via {
-    my $encoding = $_;
-    return sub { return decode( $encoding, shift ) };
-};
-
-subtype 'Encoder' => as 'CodeRef';
-coerce 'Encoder' => from 'Str' => via {
-    my $encoding = $_;
-    return sub { return encode( $encoding, shift ) };
-};
-
 has 'input_decoder' => (
     'is'      => 'ro',
     'isa'     => 'Decoder',
@@ -76,7 +63,7 @@ DataFlow::Proc::Encoding - A encoding conversion processor
 
 =head1 VERSION
 
-version 1.111450
+version 1.111480
 
 =head1 AUTHOR
 
