@@ -5,13 +5,13 @@ use warnings;
 
 # ABSTRACT: A HTML filtering processor
 
-our $VERSION = '1.111450'; # VERSION
+our $VERSION = '1.111480'; # VERSION
 
 use Moose;
 extends 'DataFlow::Proc';
 
 use namespace::autoclean;
-use Moose::Util::TypeConstraints 1.01;
+use DataFlow::Types qw(HTMLFilterTypes);
 use HTML::TreeBuilder::XPath;
 
 has 'search_xpath' => (
@@ -22,7 +22,7 @@ has 'search_xpath' => (
 
 has 'result_type' => (
     'is'      => 'ro',
-    'isa'     => enum( [qw(NODE HTML VALUE)] ),
+    'isa'     => 'HTMLFilterTypes',
     'default' => 'HTML',
 );
 
@@ -88,7 +88,7 @@ DataFlow::Proc::HTMLFilter - A HTML filtering processor
 
 =head1 VERSION
 
-version 1.111450
+version 1.111480
 
 =head1 SYNOPSIS
 
